import pickle
import time
import os
from sqpass.passwordManager.cache import CACHE_DIR as CACHE_FILE

while True:
    if os.path.exists(CACHE_FILE) and os.path.getsize(CACHE_FILE) > 0:
        try:
            with open(CACHE_FILE, "rb") as file:
                cache = pickle.load(file)
                try:
                    if "upass" in cache:
                        value, exp_time = cache["upass"]
                        if exp_time < time.time():
                            with open(CACHE_FILE, "wb") as clear_file:
                                pickle.dump({}, clear_file)
                except ValueError:
                    pass
        except (FileNotFoundError, EOFError, pickle.UnpicklingError):
            pass

    time.sleep(1)



import os
import platform
import yaml


def get_config_path():
    os_name = platform.system()
    config_paths = {
        "Linux": os.path.expanduser("~/.config/sqpass/"),
        "Windows": os.path.expanduser("~\\AppData\\sqpass\\"),
    }
    return config_paths.get(os_name, "")


def create_default_config():
    passw_colors = {
        "passw_colors": {
            "index": "",
            "username": "",
            "appname": "",
            "password": "",
        }
    }
    return yaml.dump(passw_colors, indent=4)


def setup_config():
    CONFIG_PATH = get_config_path()
    path = os.path.join(CONFIG_PATH, "config.yaml")
    os.makedirs(os.path.dirname(path), exist_ok=True)
    with open(path, "w") as f:
        f.write(create_default_config())
        print(f"Created config file at {path}")


def get_config():
    CONFIG_PATH = get_config_path()
    if os.path.exists(CONFIG_PATH):
        with open(os.path.join(CONFIG_PATH, "config.yaml"), "r") as f:
            data = yaml.load(f, Loader=yaml.SafeLoader)
            return data



import sqlite3
import os
import platform

db_paths = {
    "Linux": os.path.expanduser("~/.local/share/sqpass/"),
    "Windows": os.path.expanduser("~\\AppData\\sqpass\\"),
}
db_dir = db_paths.get(platform.system())
db_path = os.path.join(db_dir, "pass.db")


def check_db_file():
    if os.path.exists(db_path):
        return True
    return False


def clear_db():
    if check_db_file:
        os.remove(db_path)
        print("Rebuilding database...")
        create_database()
        print("[+]Done")


def create_database():
    if not check_db_file:
        os.makedirs(db_dir)
    conn = sqlite3.connect(db_path)
    c = conn.cursor()
    print("Creating database.....")
    c.execute(
        """ CREATE TABLE
                    keys (
                    id INTEGER PRIMARY KEY AUTOINCREMENT,
                    title text,
                    key text,
                    date DATETIME DEFAULT CURRENT_TIMESTAMP
        ) """
    )

    c.execute(
        """ CREATE TABLE
                    notes (
                    id INTEGER PRIMARY KEY AUTOINCREMENT,
                    title text,
                    content text,
                    date DATETIME DEFAULT CURRENT_TIMESTAMP
        ) """
    )

    c.execute(
        """ CREATE TABLE
                    passw (
                    id INTEGER PRIMARY KEY AUTOINCREMENT,
                    app_name text,
                    username text,
                    passwd text,
                    date DATETIME DEFAULT CURRENT_TIMESTAMP
        ) """
    )

    conn.commit()
    conn.close()


if __name__ == "__main__":
    create_database()



from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

long_description = open("README.md").read()


setup(
    name="square-pass3",
    version="0.0.8",
    description="CLI Based Password Manager",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/jis4nx/square-pass",
    author="Rakibul Islam Jisan",
    author_email="jis4nx@gmail.com",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords="password_manager, encryption, aes256, cli-password-manager",
    packages=find_packages(),
    python_requires=">=3.6, <3.12",
    install_requires=[
        "pycryptodome==3.10.1",
        "prettytable==2.4.0",
        "colorama==0.4.4",
        "rich==10.15.2",
        "pyperclip",
        "psutil",
        "setuptools",
        "wheel",
        "PyYAML",
    ],
    entry_points={
        "console_scripts": [
            "sq-init=sqpass.install:setmain",
            "sq=sqpass.main:main",
        ],
    },
    project_urls={
        "Bug Reports": "https://github.com/jis4nx/square-pass/issues",
        "Funding": "https://donate.pypi.org",
        "Source": "https://github.com/jis4nx/square-pass/",
    },
)
